..
    SPDX-FileCopyrightText: 2017 Free Software Foundation Europe e.V. <https://fsfe.org>

    SPDX-License-Identifier: CC-BY-SA-4.0

.. reuse documentation master file, created by
   sphinx-quickstart on Wed Nov  1 14:41:46 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to reuse's documentation!
=================================

.. toctree::
   :maxdepth: 2

   readme
   usage
   scripts
   authors
   history
   API<api/modules>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
